#!/bin/bash

DOTFILES=$(cd "$(dirname "$0")" && pwd)

confirm() {
	local prompt="$1 [Y/n] "

	while true; do
		read -e -p "$prompt" yn
		case "$yn" in
			""    ) return 0;; # default is yes
			[Yy]* ) return 0;;
			[Nn]* ) return 1;;
			*     ) ;; # wait for yes or no
		esac
	done
}

# Install tools
if [[ "$OSTYPE" == linux-gnu* ]]; then
	confirm "Install Nix?"               && "$DOTFILES/install/install-nix.sh"
	confirm "Install Nix packages?"      && "$DOTFILES/install/install-nix-packages.sh"
elif [[ "$OSTYPE" == darwin* ]]; then
	confirm "Install Homebrew?"          && "$DOTFILES/install/install-brew.sh"
	confirm "Install Homebrew packages?" && "$DOTFILES/install/install-brew-packages.sh"
fi

# Extra steps
confirm "Set login shell?"           && "$DOTFILES/install/install-shell.sh"
confirm "Create symlinks?"           && "$DOTFILES/install/install-symlinks.sh"
confirm "Install vim plugins?"       && "$DOTFILES/install/install-vim-plugins.sh"
